from enum import IntEnum

class CompassSphereType(IntEnum):

    SaltFlash = 11,
    Aggregation = 12,
    Crystal = 13,
    DeepBlue = 14,
    GoldPiece = 15,
    Orbital = 16,
    StabLake = 17,
    Wheel = 18,
    Windmill = 19,

